@@ -1,25 +1,7 @@
-/* 43.224.0.0 - 43.231.255.255 */
-{ 736100352UL, 4294443008UL, "whois.apnic.net" },
-/* 43.236.0.0 - 43.243.255.255 */
-{ 736886784UL, 4294705152UL, "whois.apnic.net" },
-{ 737148928UL, 4294705152UL, "whois.apnic.net" },
-/* 43.245.0.0 - 43.252.255.255 */
-{ 737476608UL, 4294901760UL, "whois.apnic.net" },
-{ 737542144UL, 4294836224UL, "whois.apnic.net" },
-{ 737673216UL, 4294705152UL, "whois.apnic.net" },
-{ 737935360UL, 4294901760UL, "whois.apnic.net" },
-/* 43.254.0.0 - 43.255.255.255 */
-{ 738066432UL, 4294836224UL, "whois.apnic.net" },
-/* 45.2.0.0 - 45.3.255.255 */
-{ 755105792UL, 4294836224UL, "whois.arin.net" },
 /* 45.4.0.0 - 45.7.255.255 */
 { 755236864UL, 4294705152UL, "whois.lacnic.net" },
 /* 45.8.0.0 - 45.15.255.255 */
 { 755499008UL, 4294443008UL, "whois.ripe.net" },
-/* 45.16.0.0 - 45.31.255.255 */
-{ 756023296UL, 4293918720UL, "whois.arin.net" },
-/* 45.32.0.0 - 45.63.255.255 */
-{ 757071872UL, 4292870144UL, "whois.arin.net" },
 /* 45.64.0.0 - 45.65.15.255 */
 { 759234560UL, 4294963200UL, "whois.apnic.net" },
 { 759169024UL, 4294901760UL, "whois.apnic.net" },
@@ -34,8 +16,6 @@
 { 759300096UL, 4294836224UL, "whois.ripe.net" },
 /* 45.68.0.0 - 45.71.255.255 */
 { 759431168UL, 4294705152UL, "whois.lacnic.net" },
-/* 45.72.0.0 - 45.79.255.255 */
-{ 759693312UL, 4294443008UL, "whois.arin.net" },
 /* 45.80.0.0 - 45.95.255.255 */
 { 760217600UL, 4293918720UL, "whois.ripe.net" },
 /* 45.96.0.0 - 45.111.255.255 */
@@ -52,22 +32,16 @@
 { 769130496UL, 4294705152UL, "whois.afrinic.net" },
 { 769392640UL, 4294836224UL, "whois.afrinic.net" },
 { 769523712UL, 4294901760UL, "whois.afrinic.net" },
-/* 45.223.0.0 - 45.223.255.255 */
-{ 769589248UL, 4294901760UL, "whois.arin.net" },
 /* 45.224.0.0 - 45.239.255.255 */
 { 769654784UL, 4293918720UL, "whois.lacnic.net" },
 /* 45.240.0.0 - 45.247.255.255 */
 { 770703360UL, 4294443008UL, "whois.afrinic.net" },
 /* 45.248.0.0 - 45.255.255.255 */
 { 771227648UL, 4294443008UL, "whois.apnic.net" },
-/* 66.218.132.0 - 66.218.133.255 */
-{ 1121616896UL, 4294966784UL, "whois.arin.net" },
 /* 66.251.128.0 - 66.251.191.255 */
 { 1123778560UL, 4294950912UL, "whois.afrinic.net" },
 /* 72.44.16.0 - 72.44.31.255 */
 { 1210847232UL, 4294963200UL, "whois.lacnic.net" },
-/* 74.91.48.0 - 74.91.63.255 */
-{ 1247490048UL, 4294963200UL, "whois.arin.net" },
 /* 128.201.0.0 - 128.201.255.255 */
 { 2160656384UL, 4294901760UL, "whois.lacnic.net" },
 /* 131.196.0.0 - 131.196.255.255 */
@@ -78,12 +52,8 @@
 { 2332360704UL, 4294901760UL, "whois.apnic.net" },
 /* 139.26.0.0 - 139.26.255.255 */
 { 2333736960UL, 4294901760UL, "whois.afrinic.net" },
-/* 139.28.0.0 - 139.28.255.255 */
-{ 2333868032UL, 4294901760UL, "whois.ripe.net" },
 /* 144.48.0.0 - 144.48.255.255 */
 { 2419064832UL, 4294901760UL, "whois.apnic.net" },
-/* 144.168.0.0 - 144.168.255.255 */
-{ 2426929152UL, 4294901760UL, "whois.arin.net" },
 /* 146.196.32.0 - 146.196.127.255 */
 { 2462326784UL, 4294959104UL, "whois.apnic.net" },
 { 2462334976UL, 4294950912UL, "whois.apnic.net" },
@@ -93,24 +63,12 @@
 { 2471362560UL, 4294901760UL, "whois.ripe.net" },
 /* 149.248.0.0 - 149.248.255.255 */
 { 2516058112UL, 4294901760UL, "whois.arin.net" },
-/* 150.107.0.0 - 150.107.255.255 */
-{ 2523594752UL, 4294901760UL, "whois.apnic.net" },
-/* 150.129.0.0 - 150.129.255.255 */
-{ 2525036544UL, 4294901760UL, "whois.apnic.net" },
-/* 150.242.0.0 - 150.242.255.255 */
-{ 2532442112UL, 4294901760UL, "whois.apnic.net" },
 /* 152.89.0.0 - 152.89.255.255 */
 { 2555969536UL, 4294901760UL, "whois.ripe.net" },
-/* 154.16.0.0 - 154.16.255.255 */
-{ 2584739840UL, 4294901760UL, "whois.afrinic.net" },
 /* 157.119.0.0 - 157.119.255.255 */
 { 2641821696UL, 4294901760UL, "whois.apnic.net" },
-/* 160.19.0.0 - 160.19.15.255 */
-{ 2685599744UL, 4294963200UL, "whois.arin.net" },
 /* 160.19.20.0 - 160.19.23.255 */
 { 2685604864UL, 4294966272UL, "whois.apnic.net" },
-/* 160.19.24.0 - 160.19.31.255 */
-{ 2685605888UL, 4294965248UL, "whois.arin.net" },
 /* 160.19.36.0 - 160.19.39.255 */
 { 2685608960UL, 4294966272UL, "whois.afrinic.net" },
 /* 160.19.44.0 - 160.19.47.255 */
@@ -125,15 +83,11 @@
 { 2685623296UL, 4294966272UL, "whois.ripe.net" },
 /* 160.19.96.0 - 160.19.103.255 */
 { 2685624320UL, 4294965248UL, "whois.afrinic.net" },
-/* 160.19.104.0 - 160.19.107.255 */
-{ 2685626368UL, 4294966272UL, "whois.arin.net" },
 /* 160.19.112.0 - 160.19.143.255 */
 { 2685628416UL, 4294963200UL, "whois.afrinic.net" },
 { 2685632512UL, 4294963200UL, "whois.afrinic.net" },
 /* 160.19.152.0 - 160.19.155.255 */
 { 2685638656UL, 4294966272UL, "whois.afrinic.net" },
-/* 160.19.160.0 - 160.19.163.255 */
-{ 2685640704UL, 4294966272UL, "whois.arin.net" },
 /* 160.19.168.0 - 160.19.175.255 */
 { 2685642752UL, 4294965248UL, "whois.lacnic.net" },
 /* 160.19.180.0 - 160.19.183.255 */
@@ -181,8 +135,6 @@
 /* 160.20.160.0 - 160.20.207.255 */
 { 2685706240UL, 4294959104UL, "whois.lacnic.net" },
 { 2685714432UL, 4294963200UL, "whois.lacnic.net" },
-/* 160.20.208.0 - 160.20.211.255 */
-{ 2685718528UL, 4294966272UL, "whois.arin.net" },
 /* 160.20.213.0 - 160.20.213.255 */
 { 2685719808UL, 4294967040UL, "whois.afrinic.net" },
 /* 160.20.214.0 - 160.20.215.255 */
@@ -201,18 +153,12 @@
 { 2685723136UL, 4294966784UL, "whois.afrinic.net" },
 /* 160.20.229.0 - 160.20.229.255 */
 { 2685723904UL, 4294967040UL, "whois.ripe.net" },
-/* 160.20.230.0 - 160.20.231.255 */
-{ 2685724160UL, 4294966784UL, "whois.arin.net" },
-/* 160.20.232.0 - 160.20.239.255 */
-{ 2685724672UL, 4294965248UL, "whois.arin.net" },
 /* 160.20.242.0 - 160.20.243.255 */
 { 2685727232UL, 4294966784UL, "whois.lacnic.net" },
 /* 160.20.246.0 - 160.20.247.255 */
 { 2685728256UL, 4294966784UL, "whois.lacnic.net" },
 /* 160.20.248.0 - 160.20.249.255 */
 { 2685728768UL, 4294966784UL, "whois.ripe.net" },
-/* 160.20.251.0 - 160.20.251.255 */
-{ 2685729536UL, 4294967040UL, "whois.arin.net" },
 /* 160.20.252.0 - 160.20.255.255 */
 { 2685729792UL, 4294966272UL, "whois.afrinic.net" },
 /* 160.202.8.0 - 160.202.15.255 */
@@ -221,8 +167,6 @@
 { 2697596928UL, 4294963200UL, "whois.ripe.net" },
 /* 160.202.32.0 - 160.202.63.255 */
 { 2697601024UL, 4294959104UL, "whois.apnic.net" },
-/* 160.202.64.0 - 160.202.127.255 */
-{ 2697609216UL, 4294950912UL, "whois.arin.net" },
 /* 160.202.128.0 - 160.202.255.255 */
 { 2697625600UL, 4294934528UL, "whois.apnic.net" },
 /* 160.238.0.0 - 160.238.0.255 */
@@ -234,24 +178,15 @@
 { 2699956224UL, 4294966272UL, "whois.apnic.net" },
 /* 160.238.21.0 - 160.238.21.255 */
 { 2699957504UL, 4294967040UL, "whois.ripe.net" },
-/* 160.238.22.0 - 160.238.23.255 */
-{ 2699957760UL, 4294966784UL, "whois.arin.net" },
 /* 160.238.24.0 - 160.238.29.255 */
 { 2699958272UL, 4294966272UL, "whois.lacnic.net" },
 { 2699959296UL, 4294966784UL, "whois.lacnic.net" },
-/* 160.238.31.0 - 160.238.31.255 */
-{ 2699960064UL, 4294967040UL, "whois.arin.net" },
 /* 160.238.33.0 - 160.238.33.255 */
 { 2699960576UL, 4294967040UL, "whois.apnic.net" },
 /* 160.238.34.0 - 160.238.35.255 */
 { 2699960832UL, 4294966784UL, "whois.apnic.net" },
 /* 160.238.36.0 - 160.238.39.255 */
 { 2699961344UL, 4294966272UL, "whois.ripe.net" },
-/* 160.238.41.0 - 160.238.41.255 */
-{ 2699962624UL, 4294967040UL, "whois.arin.net" },
-/* 160.238.42.0 - 160.238.47.255 */
-{ 2699962880UL, 4294966784UL, "whois.arin.net" },
-{ 2699963392UL, 4294966272UL, "whois.arin.net" },
 /* 160.238.48.0 - 160.238.49.255 */
 { 2699964416UL, 4294966784UL, "whois.afrinic.net" },
 /* 160.238.50.0 - 160.238.50.255 */
@@ -272,8 +207,6 @@
 { 2699976704UL, 4294966272UL, "whois.ripe.net" },
 /* 160.238.101.0 - 160.238.101.255 */
 { 2699977984UL, 4294967040UL, "whois.afrinic.net" },
-/* 160.238.102.0 - 160.238.103.255 */
-{ 2699978240UL, 4294966784UL, "whois.arin.net" },
 /* 160.238.104.0 - 160.238.111.255 */
 { 2699978752UL, 4294965248UL, "whois.lacnic.net" },
 /* 160.238.112.0 - 160.238.127.255 */
@@ -288,31 +221,8 @@
 { 2718746624UL, 4294965248UL, "whois.ripe.net" },
 /* 162.12.208.0 - 162.12.215.255 */
 { 2718748672UL, 4294965248UL, "whois.apnic.net" },
-/* 162.12.216.0 - 162.12.219.255 */
-{ 2718750720UL, 4294966272UL, "whois.arin.net" },
-/* 162.12.224.0 - 162.12.235.255 */
-{ 2718752768UL, 4294965248UL, "whois.arin.net" },
-{ 2718754816UL, 4294966272UL, "whois.arin.net" },
 /* 162.12.240.0 - 162.12.247.255 */
 { 2718756864UL, 4294965248UL, "whois.apnic.net" },
-/* 163.47.4.0 - 163.47.18.255 */
-{ 2737767424UL, 4294966272UL, "whois.apnic.net" },
-{ 2737768448UL, 4294965248UL, "whois.apnic.net" },
-{ 2737770496UL, 4294966784UL, "whois.apnic.net" },
-{ 2737771008UL, 4294967040UL, "whois.apnic.net" },
-/* 163.47.20.0 - 163.47.21.255 */
-{ 2737771520UL, 4294966784UL, "whois.apnic.net" },
-/* 163.47.32.0 - 163.47.45.255 */
-{ 2737774592UL, 4294965248UL, "whois.apnic.net" },
-{ 2737776640UL, 4294966272UL, "whois.apnic.net" },
-{ 2737777664UL, 4294966784UL, "whois.apnic.net" },
-/* 163.47.47.0 - 163.47.255.255 */
-{ 2737778432UL, 4294967040UL, "whois.apnic.net" },
-{ 2737778688UL, 4294963200UL, "whois.apnic.net" },
-{ 2737782784UL, 4294950912UL, "whois.apnic.net" },
-{ 2737799168UL, 4294934528UL, "whois.apnic.net" },
-/* 163.53.0.0 - 163.53.255.255 */
-{ 2738159616UL, 4294901760UL, "whois.apnic.net" },
 /* 164.160.0.0 - 164.160.255.255 */
 { 2761949184UL, 4294901760UL, "whois.afrinic.net" },
 /* 164.163.0.0 - 164.163.255.255 */
@@ -365,14 +275,8 @@
 { 3227254272UL, 4294967040UL, "whois.lacnic.net" },
 /* 192.92.154.0 - 192.92.154.255 */
 { 3227294208UL, 4294967040UL, "whois.lacnic.net" },
-/* 192.94.77.0 - 192.94.77.255 */
-{ 3227405568UL, 4294967040UL, "whois.arin.net" },
 /* 192.94.78.0 - 192.94.78.255 */
 { 3227405824UL, 4294967040UL, "whois.ripe.net" },
-/* 192.107.1.0 - 192.107.1.255 */
-{ 3228238080UL, 4294967040UL, "whois.arin.net" },
-/* 192.133.103.0 - 192.133.103.255 */
-{ 3229968128UL, 4294967040UL, "whois.arin.net" },
 /* 192.135.90.0 - 192.135.91.255 */
 { 3230095872UL, 4294966784UL, "whois.apnic.net" },
 /* 192.135.95.0 - 192.135.95.255 */
@@ -387,8 +291,6 @@
 { 3230400768UL, 4294967040UL, "whois.lacnic.net" },
 /* 192.140.2.0 - 192.140.3.255 */
 { 3230401024UL, 4294966784UL, "whois.ripe.net" },
-/* 192.140.4.0 - 192.140.7.255 */
-{ 3230401536UL, 4294966272UL, "whois.arin.net" },
 /* 192.140.8.0 - 192.140.15.255 */
 { 3230402560UL, 4294965248UL, "whois.lacnic.net" },
 /* 192.140.16.0 - 192.140.127.255 */
@@ -415,8 +317,6 @@
 { 3230683136UL, 4294963200UL, "whois.apnic.net" },
 /* 192.144.96.0 - 192.144.127.255 */
 { 3230687232UL, 4294959104UL, "whois.lacnic.net" },
-/* 192.144.128.0 - 192.144.255.255 */
-{ 3230695424UL, 4294934528UL, "whois.arin.net" },
 /* 192.145.0.0 - 192.145.127.255 */
 { 3230728192UL, 4294934528UL, "whois.ripe.net" },
 /* 192.145.128.0 - 192.145.191.255 */
@@ -429,34 +329,22 @@
 { 3230786560UL, 4294966784UL, "whois.apnic.net" },
 /* 192.145.230.0 - 192.145.230.255 */
 { 3230787072UL, 4294967040UL, "whois.afrinic.net" },
-/* 192.147.11.0 - 192.147.11.255 */
-{ 3230862080UL, 4294967040UL, "whois.arin.net" },
 /* 192.153.12.0 - 192.153.12.255 */
 { 3231255552UL, 4294967040UL, "whois.lacnic.net" },
 /* 192.156.144.0 - 192.156.144.255 */
 { 3231485952UL, 4294967040UL, "whois.apnic.net" },
-/* 192.156.202.0 - 192.156.202.255 */
-{ 3231500800UL, 4294967040UL, "whois.arin.net" },
 /* 192.156.220.0 - 192.156.220.255 */
 { 3231505408UL, 4294967040UL, "whois.apnic.net" },
 /* 192.172.232.0 - 192.172.232.255 */
 { 3232557056UL, 4294967040UL, "whois.ripe.net" },
-/* 192.172.244.0 - 192.172.244.255 */
-{ 3232560128UL, 4294967040UL, "whois.arin.net" },
-/* 192.188.81.0 - 192.188.81.255 */
-{ 3233566976UL, 4294967040UL, "whois.arin.net" },
 /* 192.188.82.0 - 192.188.83.255 */
 { 3233567232UL, 4294966784UL, "whois.apnic.net" },
 /* 192.188.248.0 - 192.188.248.255 */
 { 3233609728UL, 4294967040UL, "whois.ripe.net" },
 /* 192.197.113.0 - 192.197.113.255 */
 { 3234164992UL, 4294967040UL, "whois.apnic.net" },
-/* 192.231.238.0 - 192.231.238.255 */
-{ 3236425216UL, 4294967040UL, "whois.arin.net" },
 /* 192.251.230.0 - 192.251.230.255 */
 { 3237733888UL, 4294967040UL, "whois.ripe.net" },
-/* 198.17.79.0 - 198.17.79.255 */
-{ 3323023104UL, 4294967040UL, "whois.arin.net" },
 /* 198.97.38.0 - 198.97.38.255 */
 { 3328255488UL, 4294967040UL, "whois.lacnic.net" },
 /* 199.21.172.0 - 199.21.175.255 */
@@ -475,14 +363,8 @@
 { 3437308416UL, 4294966784UL, "whois.lacnic.net" },
 /* 205.211.83.0 - 205.211.83.255 */
 { 3453178624UL, 4294967040UL, "whois.ripe.net" },
-/* 207.115.112.0 - 207.115.127.255 */
-{ 3480449024UL, 4294963200UL, "whois.arin.net" },
-/* 208.73.240.0 - 208.73.243.255 */
-{ 3494506496UL, 4294966272UL, "whois.arin.net" },
 /* 208.85.156.0 - 208.85.159.255 */
 { 3495271424UL, 4294966272UL, "whois.afrinic.net" },
-/* 209.107.128.0 - 209.107.191.255 */
-{ 3513483264UL, 4294950912UL, "whois.arin.net" },
 /* 216.98.208.0 - 216.98.223.255 */
 { 3630354432UL, 4294963200UL, "whois.lacnic.net" },
 /* 216.250.96.0 - 216.250.111.255 */
